import Vue from 'vue'

import Cookies from 'js-cookie'

import 'normalize.css/normalize.css' // a modern alternative to CSS resets

import Element from 'element-ui'
import './styles/element-variables.scss'
// import enLang from 'element-ui/lib/locale/lang/en'// 如果使用中文语言包请默认支持，无需额外引入，请删除该依赖

import '@/styles/index.scss' // global css

import App from './App'
import store from './store'
import router from './router'

import './icons' // icon
import './permission' // permission control
import './utils/error-log' // error log
import './utils/dialog-helper' // modal in root
import './utils/drawer-helper' // 抽屉 in root

import * as filters from './filters' // global filters

import './components'
import './containers'

import '@/assets/common.css'

import echarts from 'echarts'

Vue.prototype.$echarts = echarts

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online ! ! !
 */
if (process.env.NODE_ENV === 'production') {
  console.log('production')
  const { mockXHR } = require('../mock')
  mockXHR()
}

Vue.use(Element, {
  size: Cookies.get('size') || 'small' // set element-ui default size
  // locale: enLang // 如果使用中文，无需设置，请删除
})

// register global utility filters
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})

Vue.config.productionTip = false

Vue.prototype.bus = new Vue()

window.UEDITOR_CONFIG = `${process.env.VUE_APP_BASE_API}/oss/ueditor/ueditor-action`
window.UEDITOR_SERVER_URL = `${process.env.VUE_APP_BASE_API}/oss/ueditor/ueditor-action`

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
