import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/* Router Modules */
// import componentsRouter from './modules/components'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [{
  path: '/redirect',
  component: Layout,
  hidden: true,
  children: [{
    path: '/redirect/:path(.*)',
    component: () => import('@/views/redirect/index')
  }]
}, {
  path: '/login',
  component: () => import('@/views/login/index'),
  hidden: true
}, {
  path: '/auth-redirect',
  component: () => import('@/views/login/auth-redirect'),
  hidden: true
}, {
  path: '/404',
  component: () => import('@/views/error-page/404'),
  hidden: true
}, {
  path: '/401',
  component: () => import('@/views/error-page/401'),
  hidden: true
}, {
  path: '/',
  component: Layout,
  redirect: '/dashboard',
  children: [{
    path: 'dashboard',
    component: () => import('@/views/welcome/index'),
    name: 'Dashboard',
    meta: { title: '首页', icon: 'dashboard', affix: true }
  }]
}]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [{
  path: '/base',
  component: Layout,
  redirect: 'noRedirect',
  name: '基础管理',
  meta: {
    title: '基础管理',
    icon: 'dashboard'
  },
  children: [{
    path: '/indexModule/index',
    component: () => import('@/views/indexModuleManagement/index'),
    name: 'indexModuleManagement',
    meta: { title: '首页模块', icon: 'dashboard', affix: false }
  }, {
    path: '/indexRecommend/index',
    component: () => import('@/views/indexRecommendManagement/index'),
    name: 'indexRecommendManagement',
    meta: { title: '内容上新', icon: 'dashboard', affix: false }
  }, {
    path: '/banner/index',
    component: () => import('@/views/bannerManagement/index'),
    name: 'bannerManagement',
    meta: { title: 'Banner管理', icon: 'dashboard', affix: false }
  }]
}, {
  path: '/content',
  component: Layout,
  redirect: 'noRedirect',
  name: '内容管理',
  meta: {
    title: '内容管理',
    icon: 'dashboard'
  },
  children: [{
    path: '/article/index',
    component: () => import('@/views/articleManagement/index'),
    name: 'articleManagement',
    meta: { title: '文章管理', icon: 'dashboard', affix: false }
  }, {
    path: '/article_collect/index',
    component: () => import('@/views/articleCollectManagement/index'),
    name: 'articleCollectManagement',
    meta: { title: '文章收藏管理', icon: 'dashboard', affix: false }
  }, {
    path: '/article_pv/index',
    component: () => import('@/views/articlePvManagement/index'),
    name: 'articlePvManagement',
    meta: { title: '文章PV管理', icon: 'dashboard', affix: false }
  }, {
    path: '/artilce_echart/index',
    component: () => import('@/views/artilceEchart/index'),
    name: 'artilceEchart',
    meta: { title: '文章报表', icon: 'dashboard', affix: false }
  }, {
    path: '/comment/index',
    component: () => import('@/views/commentManagement/index'),
    name: 'commentManagement',
    meta: { title: '评论管理', icon: 'dashboard', affix: false }
  }, {
    path: '/tag/index',
    component: () => import('@/views/tagManagement/index'),
    name: 'tagManagement',
    meta: { title: '标签管理', icon: 'dashboard', affix: false }
  }, {
    path: '/doctor/index',
    component: () => import('@/views/doctorManagement/index'),
    name: 'doctorManagement',
    meta: { title: '医生管理', icon: 'dashboard', affix: false }
  }]
}, {
  path: '/baby',
  component: Layout,
  redirect: '/baby/index',
  children: [{
    path: '/baby/index',
    component: () => import('@/views/babyManagement/index'),
    name: 'babyManagement',
    meta: { title: '用户婴儿表', icon: 'dashboard', affix: false }
  }]
}, {
  path: '/account',
  component: Layout,
  redirect: '/account/index',
  children: [{
    path: '/account/index',
    component: () => import('@/views/accountManagement/index'),
    name: 'accountManagement',
    meta: { title: '账号管理', icon: 'dashboard', affix: false, roles: ['SUPER_ADMIN'] }
  }]
},
/** when your routing map is too long, you can split it into small modules **/
// componentsRouter,

// {
//   path: '/error',
//   component: Layout,
//   redirect: 'noRedirect',
//   name: 'ErrorPages',
//   meta: {
//     title: 'Error Pages',
//     icon: '404'
//   },
//   children: [
//     {
//       path: '401',
//       component: () => import('@/views/error-page/401'),
//       name: 'Page401',
//       meta: { title: '401', noCache: true }
//     },
//     {
//       path: '404',
//       component: () => import('@/views/error-page/404'),
//       name: 'Page404',
//       meta: { title: '404', noCache: true }
//     }
//   ]
// },

// 404 page must be placed at the end !!!
{ path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
